# Generated by Django 2.1.7 on 2020-08-17 17:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('e_mail', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='email',
            name='assunto',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='email',
            name='conteudo',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='email',
            name='endereco',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='endereco_email', to='e_mail.EmailEndereco'),
        ),
        migrations.AlterField(
            model_name='email',
            name='nm_descritivo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='email',
            name='variaveis',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='emailendereco',
            name='email',
            field=models.EmailField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='emailendereco',
            name='host',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='emailendereco',
            name='password',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='emailendereco',
            name='port',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='emaillog',
            name='destinatario',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='emaillog',
            name='email',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='e_mail.Email'),
        ),
        migrations.AlterField(
            model_name='emaillog',
            name='retorno',
            field=models.TextField(blank=True, null=True),
        ),
    ]
