# Generated by Django 2.1.7 on 2020-08-20 13:03

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0018_auto_20200806_1830'),
        ('filial', '0021_auto_20200818_1832'),
    ]

    operations = [
        migrations.AddField(
            model_name='area',
            name='responsavel',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='funcionario.Funcionario'),
        ),
        migrations.AddField(
            model_name='filialarea',
            name='responsavel',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='funcionario.Funcionario'),
        ),
    ]
