# Generated by Django 2.1.7 on 2020-08-13 04:21

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('core', '0017_auto_20200806_1830'),
    ]

    operations = [
        migrations.CreateModel(
            name='Email',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(blank=True, null=True)),
                ('usr_insercao', models.IntegerField(blank=True, null=True)),
                ('usr_edicao', models.IntegerField(blank=True, null=True)),
                ('usr_delete', models.IntegerField(blank=True, null=True)),
                ('origem_insercao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, primary_key=True, serialize=False)),
                ('nm_descritivo', models.CharField(max_length=200, null=True)),
                ('assunto', models.CharField(max_length=200, null=True)),
                ('conteudo', models.TextField(null=True)),
                ('variaveis', models.TextField(null=True)),
            ],
            options={
                'db_table': 'comunicacao_email',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='EmailEndereco',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(blank=True, null=True)),
                ('usr_insercao', models.IntegerField(blank=True, null=True)),
                ('usr_edicao', models.IntegerField(blank=True, null=True)),
                ('usr_delete', models.IntegerField(blank=True, null=True)),
                ('origem_insercao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('email', models.EmailField(max_length=200, null=True)),
                ('port', models.IntegerField(null=True)),
                ('host', models.CharField(max_length=200, null=True)),
                ('password', models.CharField(max_length=200, null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emailendereco_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emailendereco_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emailendereco_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'comunicacao_email_endereco',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='EmailLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(blank=True, null=True)),
                ('usr_insercao', models.IntegerField(blank=True, null=True)),
                ('usr_edicao', models.IntegerField(blank=True, null=True)),
                ('usr_delete', models.IntegerField(blank=True, null=True)),
                ('origem_insercao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('destinatario', models.CharField(max_length=200, null=True)),
                ('retorno', models.TextField(null=True)),
                ('email', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='e_mail.Email')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emaillog_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emaillog_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emaillog_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'comunicacao_email_log',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name='email',
            name='endereco',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='endereco_email', to='e_mail.EmailEndereco'),
        ),
        migrations.AddField(
            model_name='email',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_email_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='email',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_email_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='email',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_email_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
    ]
