# Generated by Django 2.1.7 on 2020-08-09 21:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0028_auto_20200806_2317'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cartao',
            name='cartao_token',
        ),
        migrations.AddField(
            model_name='cartao',
            name='password',
            field=models.CharField(max_length=50, null=True),
        ),
    ]
