# Generated by Django 2.1.7 on 2020-08-21 13:53

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0017_auto_20200806_1830'),
        ('cliente', '0034_auto_20200821_1053'),
    ]

    operations = [
        migrations.AddField(
            model_name='cartao',
            name='adquirente',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_cartao_adquirente', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('adquirente_codigo'), 'tipo': compositefk.fields.LocalFieldValue('adquirente_tipo')}),
        ),
        migrations.AddField(
            model_name='cartao',
            name='adquirente_codigo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='adquirente_tipo',
            field=models.CharField(default='CLIENTE.CARTAO.ADQUIRENTE', max_length=200, null=True),
        ),
    ]
