# Generated by Django 2.1.7 on 2020-08-21 13:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0018_auto_20200806_1830'),
    ]

    operations = [
        migrations.AddField(
            model_name='funcionario',
            name='rg_form',
            field=models.CharField(max_length=15, null=True),
        ),
    ]
