# Generated by Django 2.1.7 on 2020-08-18 21:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('filial', '0019_auto_20200818_1826'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='filialservico',
            name='cd_filial',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='servico',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='tipo',
        ),
        migrations.RemoveField(
            model_name='filial',
            name='servicos',
        ),
        migrations.DeleteModel(
            name='FilialServico',
        ),
        migrations.DeleteModel(
            name='Servico',
        ),
    ]
