# Generated by Django 2.1.7 on 2020-08-10 01:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0031_auto_20200809_2234'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cartao',
            name='password',
            field=models.CharField(max_length=200, null=True),
        ),
    ]
