# Generated by Django 2.1.7 on 2020-08-24 18:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0017_auto_20200806_1830'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tipo',
            name='codigo',
            field=models.CharField(max_length=200, null=True),
        ),
    ]
