# Generated by Django 2.1.7 on 2020-08-24 17:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sistema', '0010_auto_20200806_1830'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='perfil',
            table='sistema_perfil',
        ),
        migrations.AlterModelTable(
            name='perfilpontofuncao',
            table='sistema_perfilpontofuncao',
        ),
    ]
