# Generated by Django 2.1.7 on 2020-08-11 02:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0032_auto_20200809_2237'),
    ]

    operations = [
        migrations.AddField(
            model_name='cartao',
            name='pagamento_nome',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='password_tamanho',
            field=models.IntegerField(null=True),
        ),
    ]
