# Generated by Django 2.1.7 on 2020-08-17 17:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0030_auto_20200806_1830'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bula',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='categoria_pai',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Categoria'),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='dat_fim',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='dat_ini',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='per_desc',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='prioridade',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='qtd_fim_desc',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='qtd_ini_desc',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='tipo',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.TipoDesconto'),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='valor_desc',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='desconto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Desconto'),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='produtopreco',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.ProdutoPreco'),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='cd_filial',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='filial.Filial'),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='quantidade',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='descricao',
            field=models.CharField(blank=True, max_length=500, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='descricao',
            field=models.CharField(blank=True, max_length=500, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='nm_ecommerce',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='dat_fim',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='dat_ini',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='altura_ecommerce',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='categoria_principal',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='categoria_principal', to='produto.Categoria'),
        ),
        migrations.AlterField(
            model_name='produto',
            name='cd_externo',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='descricao',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='descricao_ecommerce',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='fabricante',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='fornecedor.Fabricante'),
        ),
        migrations.AlterField(
            model_name='produto',
            name='imagem',
            field=models.FileField(blank=True, default='produtos/caixa-nissei.jpg', null=True, upload_to='produtos'),
        ),
        migrations.AlterField(
            model_name='produto',
            name='is_ecommerce',
            field=models.BooleanField(blank=True, default=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='is_pbm',
            field=models.BooleanField(blank=True, default=False, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='is_retencao_receita',
            field=models.BooleanField(blank=True, default=False, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='is_venda_controlada',
            field=models.BooleanField(blank=True, default=False, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='largura_ecommerce',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='marca',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='marca', to='produto.Marca'),
        ),
        migrations.AlterField(
            model_name='produto',
            name='nm_ecommerce',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='peso_ecommerce',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='produto_pai',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produto',
            name='profundidade_ecommerce',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='qtd_max_venda_ecommerce',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='qtd_min_venda_ecommerce',
            field=models.IntegerField(blank=True, default=1, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='tipo_produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Tipo'),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='bula',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Bula'),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='categoria',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Categoria'),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='is_principal',
            field=models.BooleanField(blank=True, default=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='especialidade',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Especialidade'),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='grupo',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Grupo'),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='imagem',
            field=models.FileField(blank=True, default='produtos/caixa-nissei.jpg', null=True, upload_to='produtos'),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='kit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Kit'),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='precolista',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.PrecoLista'),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='valor',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='principio_ativo',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.PrincipioAtivo'),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='tipo_receita',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.TipoReceita'),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='nm_descritivo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='descricao',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='tipo',
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
    ]
